pm4py.algo.discovery.inductive package
======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.inductive.util
   pm4py.algo.discovery.inductive.variants

Submodules
----------

pm4py.algo.discovery.inductive.algorithm module
-----------------------------------------------

.. automodule:: pm4py.algo.discovery.inductive.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.inductive.parameters module
------------------------------------------------

.. automodule:: pm4py.algo.discovery.inductive.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.inductive
   :members:
   :undoc-members:
   :show-inheritance:
